@@ -15,7 +15,7 @@ require Exporter;
 *import = \&Exporter::import;
 @EXPORT_OK = qw(NOCHAR MAP8_BINFILE_MAGIC_HI MAP8_BINFILE_MAGIC_LO);
 
-$VERSION = '0.07';  # $Id: Map8.pm,v 1.21 1999/06/02 18:34:40 gisle Exp $
+$VERSION = '0.09';  # $Id: Map8.pm,v 1.22 1999/09/14 12:13:13 gisle Exp $
 #$DEBUG++;
 
 bootstrap Unicode::Map8 $VERSION;
@@ -54,6 +54,8 @@ sub new
     my $self;
     if (@_) {
 	my $file = shift;
+	$file = $file->{ID} if ref($file); # Unicode::Map compatibility
+
 	if ($file =~ /\.bin$/) {
 	    $self = Unicode::Map8::_new_binfile($file);
 	} elsif ($file =~ /\.txt$/) {
@@ -94,6 +96,11 @@ sub unmapped_to16
     "";
 }
 
+# Some Unicode::Map compatibility stuff
+
+*from_unicode = \&to8;
+*to_unicode   = \&to16;
+
 1;
 
 __END__
